==> estateplat-common-1.2.4-20241031.032451-1259-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZlcxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengchaoyi@gtmap.cn">zhengchaoyi</a>
 * @description 资料查询记录表
 * @date 2024-10-30
 */
@Table(name = "BDC_ZLCXJL")
public class BdcZlcxjl {
    @Id
    private String sqdh; //申请单号
    //申请类型代码
    private String sqlxdm;
    //申请人名称
    private String sqrmc;
    //邮寄地址
    private String yjdz;
    //申请人证件号
    private String sqrzjh;
    //申请人联系电话
    private String sqrlxdh;
    //查询时间
    private Date cxsj;

    public String getSqdh() {
        return sqdh;
    }

    public void setSqdh(String sqdh) {
        this.sqdh = sqdh;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getYjdz() {
        return yjdz;
    }

    public void setYjdz(String yjdz) {
        this.yjdz = yjdz;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }

    public String getSqrlxdh() {
        return sqrlxdh;
    }

    public void setSqrlxdh(String sqrlxdh) {
        this.sqrlxdh = sqrlxdh;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }
}

==> estateplat-common-1.2.4-20241101.091621-1262-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZlcxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengchaoyi@gtmap.cn">zhengchaoyi</a>
 * @description 资料查询记录表
 * @date 2024-10-30
 */
@Table(name = "BDC_ZLCXJL")
public class BdcZlcxjl {
    @Id
    private String sqdh; //申请单号
    //申请类型代码 1：原始资料查询2：委托查询3：利害关系人查询
    private String sqlxdm;
    //申请人名称
    private String sqrmc;
    //邮寄地址
    private String yjdz;
    //申请人证件号
    private String sqrzjh;
    //申请人联系电话
    private String sqrlxdh;
    //查询时间
    private Date cxsj;
    //审核状态
    private String shzt;

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getSqdh() {
        return sqdh;
    }

    public void setSqdh(String sqdh) {
        this.sqdh = sqdh;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getYjdz() {
        return yjdz;
    }

    public void setYjdz(String yjdz) {
        this.yjdz = yjdz;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }

    public String getSqrlxdh() {
        return sqrlxdh;
    }

    public void setSqrlxdh(String sqrlxdh) {
        this.sqrlxdh = sqrlxdh;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }
}
